@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-from __future__ import absolute_import
 import logging
 import six.moves.urllib.parse
 
@@ -75,11 +73,11 @@ class ForgePastebin(Application):
         return links
 
     def admin_menu(self):
-        return super(ForgePastebin, self).admin_menu()
+        return super().admin_menu()
 
     def install(self, project):
         'Set up any default permissions and roles here'
-        super(ForgePastebin, self).install(project)
+        super().install(project)
         # Setup permissions
         role_anon = M.ProjectRole.anonymous()._id
         role_member = M.ProjectRole.by_name('Member')._id
@@ -94,7 +92,7 @@ class ForgePastebin(Application):
 
     def uninstall(self, project):
         "Remove all the tool's artifacts from the database"
-        super(ForgePastebin, self).uninstall(project)
+        super().uninstall(project)
 
 
 class W:
@@ -195,15 +193,15 @@ class PasteController(BaseController):
             raise exc.HTTPNotFound()
 
     @without_trailing_slash
-    @expose('jinja:forgepastebin:templates/paste/paste.js', content_type=str('text/javascript'))
+    @expose('jinja:forgepastebin:templates/paste/paste.js', content_type='text/javascript')
     @expose('jinja:forgepastebin:templates/paste/paste.html')
     # TODO: only one @expose and user override_template
     def index(self, **kw):
         if self.paste.deleted:
             raise exc.HTTPNotFound()
         if request.path.endswith('.js'):
-            response.content_type = str('text/javascript')
-            csslink = ew.CSSLink('tool/%s/%s' % (c.app.config.tool_name.lower(), 'css/pygments.css'))
+            response.content_type = 'text/javascript'
+            csslink = ew.CSSLink('tool/{}/{}'.format(c.app.config.tool_name.lower(), 'css/pygments.css'))
             g.resource_manager.register(csslink)
             css = six.moves.urllib.parse.urljoin('//%s' % request.host, csslink.url())
             return dict(paste=json.dumps(self.paste.html()), js=True, csslink=json.dumps(css))
