@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-from __future__ import absolute_import
 from ming import schema as S
 from ming.orm import FieldProperty, Mapper
 from ming.utils import LazyProperty
@@ -9,7 +7,7 @@ from allura import model as M
 
 class Paste(M.Artifact):
     class __mongometa__:
-        name = str('paste')
+        name = 'paste'
         #indexes = [ ]
     type_s='Paste'
 
@@ -38,7 +36,7 @@ class Paste(M.Artifact):
         return highlight(self.text, lexer, formatter)
 
     def index(self):
-        result = super(Paste, self).index()
+        result = super().index()
         result.update(
             creator_id_s=self.creator_id,
             creator_s=self.creator.username,
