@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-from __future__ import absolute_import
 import ew as ew_core
 from ew import jinja2_ew as ew
 
@@ -15,8 +13,8 @@ class PasteLanguage(ew.SingleSelectField):
 
     def options(self):
         from pygments.lexers import get_all_lexers
-        langs = sorted([(item[0], item[1][0])
-                        for item in get_all_lexers()])
+        langs = sorted((item[0], item[1][0])
+                        for item in get_all_lexers() if len(item[1]))
         options = [ew.Option(html_value='', label='<auto detect>')]
         options.extend([ew.Option(html_value=l[1], label=l[0])
                         for l in langs])
@@ -27,7 +25,7 @@ class PasteForm(f.ForgeForm):
     template='jinja:forgepastebin:templates/widgets/paste_form.html'
     @property
     def fields(self):
-        fields = ew_core.NameList(super(PasteForm, self).fields)
+        fields = ew_core.NameList(super().fields)
         fields.append(PasteEdit(name='text',
             attrs={'style':'height:15em; width:745px; font-family:monospace'}))
         fields.append(PasteLanguage(name='lang'))
@@ -41,5 +39,5 @@ class PasteForm(f.ForgeForm):
             ctx['value'] = value
         display = field.display(**ctx)
         if ctx['errors'] and field.show_errors and not ignore_errors:
-            display = "%s<div class='error'>%s</div>" % (display, ctx['errors'])
+            display = "{}<div class='error'>{}</div>".format(display, ctx['errors'])
         return display
